@@ -1,12 +1,26 @@
 #!/usr/bin/env python3
 import typing
-from subprocess import Popen, CalledProcessError
+from sys import argv
 from os import environ
+from json import loads
+from subprocess import Popen, CalledProcessError
 
 
 class CommonHarnessLib:
 
-    def __init__(self, enable_s3: bool = True):
+    def __init__(self, enable_s3: bool = True, ignore_json_args: bool = False):
+        # Get JSON parameters from harness
+        if not ignore_json_args:
+            try:
+                loads(argv[1])
+            except IndexError:
+                raise ValueError("Harness JSON args not given.")
+            except ValueError:
+                raise ValueError("Invalid JSON harness args.")
+            except Exception as e:
+                raise ValueError(type(e).__name__ + ": " + e)
+
+        # Deal with s3 initialization
         if enable_s3:
             # Only import s3 libraries if s3 is enabled (unholy but efficient)
             import boto3
